@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2015 Luca Falavigna
+# Copyright (C) 2007-2016 Luca Falavigna
 # Copyright (C) 2010 Alessio Treglia
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
@@ -117,7 +117,7 @@ class Build:
             error(_('Distribution %s is disabled') % self.distribution)
             raise DebomaticError
         if dom.opts.has_section('crossbuild'):
-            if dom.opts.get('crossbuild', 'crossbuild'):
+            if dom.opts.getboolean('crossbuild', 'crossbuild'):
                 self.hostarchitecture = dom.opts.get('crossbuild',
                                                      'hostarchitecture')
         try:
@@ -164,7 +164,8 @@ class Build:
                    '%s-%s-debomatic' % (self.distribution, architecture),
                    self.dscfile]
         if self.hostarchitecture:
-            command.insert(6, '--host=%s' % self.hostarchitecture)
+            command.pop(5)
+            command.insert(5, '--host=%s' % self.hostarchitecture)
         if self.changesfile:
             with open(self.upload, 'r') as fd:
                 data = fd.read()
@@ -177,9 +178,12 @@ class Build:
                                findall(' \S+ \((\S+)\) \S+; ', data)[-1])
             except IndexError:
                 pass
+            with open(os.path.join(self.incoming, self.changesfile)) as fd:
+                data = fd.read()
+            for resolver in findall('Debomatic-Resolver: (\S+)', data):
+                command.insert(-1, '--build-dep-resolver=%s' % resolver)
         suite = dom.dists.get(self.distribution, 'suite')
-        if not (self.distribution == suite or
-                self.distribution.startswith(suite)):
+        if self.distribution != suite:
             command.insert(-1, '--build-dep-resolver=aptitude')
         if self.binnmu:
             command.insert(-1, '--binNMU=%s' % self.binnmu[0])
@@ -208,34 +212,37 @@ class Build:
                                        ext[os.path.splitext(file)[1]])
                     except IndexError:
                         pass
-        for sbuildcommand in self._commands():
+        for sbuildcommand in self._commands(self.distribution, architecture,
+                                            packageversion):
             command.insert(-1, sbuildcommand)
-        if self.hostarchitecture:
-            command.insert(-1, '--chroot-setup-commands=%s' %
-                           ('dpkg --add-architecture %s' %
-                            self.hostarchitecture))
         with open(os.devnull, 'w') as fd:
             try:
-                os.chdir(os.path.join(self.buildpath, 'pool', packageversion))
-                buildlink = '%s.buildlog' % packageversion
+                bpath = os.path.join(self.buildpath, 'pool', packageversion)
+                buildlink = os.path.join(bpath, '%s.buildlog' % packageversion)
                 if os.path.exists(buildlink):
                     os.unlink(buildlink)
                 os.symlink(buildlog, buildlink)
-                process = Popen(command, stdout=fd, stderr=fd)
+                process = Popen(command, stdout=fd, stderr=fd, cwd=bpath)
                 with self.buildtask.set_pid(process.pid):
                     process.wait()
+                if process.returncode:
+                    info(_("Build of %s failed") %
+                         os.path.basename(self.dscfile))
+                else:
+                    info(_("Build of %s successful") %
+                         os.path.basename(self.dscfile))
+                    mod.args.success = True
             except OSError:
-                error(_('Invoication of sbuild failed'))
-        if process.returncode == 0:
-            mod.args.success = True
+                error(_('Invocation of sbuild failed'))
         mod.execute_hook('post_build')
         self._remove_files()
-        info(_('Build of %s complete') % os.path.basename(self.dscfile))
+        debug(_('Build of %s complete') % os.path.basename(self.dscfile))
 
-    def _commands(self):
+    def _commands(self, distribution, architecture, packageversion):
         commands = []
         types = ('pre-build-commands', 'chroot-setup-commands',
-                 'starting-build-commands', 'finished-build-commands',
+                 'build-deps-failed-commands', 'starting-build-commands',
+                 'build-failed-commands', 'finished-build-commands',
                  'chroot-cleanup-commands', 'post-build-commands')
         commandsdir = dom.opts.get('chroots', 'commands')
         if os.path.isdir(commandsdir):
@@ -244,7 +251,10 @@ class Build:
                     for command in os.listdir(os.path.join(commandsdir, type)):
                         commandfile = os.path.join(commandsdir, type, command)
                         if os.access(commandfile, os.X_OK):
-                            commands.append('--%s=%s' % (type, commandfile))
+                            commands.append('--%s=%s %s %s %s' %
+                                            (type, commandfile,
+                                             packageversion, distribution,
+                                             architecture))
         if commands:
             commands.append('--log-external-command-output')
             commands.append('--log-external-command-error')
@@ -473,7 +483,6 @@ class Build:
                                     tmp.write('profile=%s\n' % profile)
                                 else:
                                     tmp.write(line)
-                        tmp.write('union-type=aufs')
                     copymode(fd.name, tmp.name)
                     move(tmp.name, fd.name)
             mod.args.success = True
