@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2015 Luca Falavigna
+# Copyright (C) 2015-2016 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -36,7 +36,7 @@ core = {'debomatic':
         'modules': {'modules': bool, 'path': str,
                     'threads': int, 'blacklist': str}}
 optional = {'crossbuild': {'crossbuild': bool, 'hostarchitecture': str}}
-modules = {'autopkgtest': {'options': str, 'gpghome': str},
+modules = {'autopkgtest': {'options': str},
            'blhc': {'options': str},
            'lintian': {'options': str},
            'mailer': {'sender': str, 'server': str, 'port': int, 'tls': bool,
