@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2015 Luca Falavigna
+# Copyright (C) 2007-2016 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -21,9 +21,8 @@ import os
 from argparse import ArgumentParser
 from configparser import ConfigParser
 from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_UN
-from logging import basicConfig as log, debug, error, getLogger, info, warning
+from logging import basicConfig as log, debug, error, getLogger, warning
 from logging import ERROR, WARNING, INFO, DEBUG
-from subprocess import check_call as call, CalledProcessError
 from time import sleep
 
 from Debomatic import dom
@@ -31,7 +30,6 @@ from .build import Build
 from .commands import Command
 from .configuration import Parser
 from .exceptions import DebomaticConffileError, DebomaticError
-from .gpg import GPGKeys
 from .modules import Module
 from .process import Process, ThreadPool
 
@@ -40,6 +38,7 @@ class Debomatic(Parser, Process):
 
     def __init__(self):
         self.daemonize = True
+        self.oneshot = False
         self.setlog('%(levelname)s: %(message)s')
         self.conffile = None
         dom.opts = ConfigParser()
@@ -49,6 +48,8 @@ class Debomatic(Parser, Process):
                             nargs=1, help='configuration file for Deb-o-Matic')
         parser.add_argument('-i', '--interactive', action='store_true',
                             help='launch Deb-o-Matic in interactive mode')
+        parser.add_argument('-o', '--oneshot', metavar='file', type=str,
+                            nargs=1, help='launch Deb-o-Matic for one build')
         parser.add_argument('-q', '--quit', action='store_true',
                             help='terminate Deb-o-Matic processes')
         args = parser.parse_args()
@@ -59,6 +60,8 @@ class Debomatic(Parser, Process):
             self.conffile = args.configfile[0]
         if args.interactive:
             self.daemonize = False
+        if args.oneshot:
+            self.oneshot = args.oneshot[0]
         try:
             self.parse_configfiles()
         except DebomaticConffileError:
@@ -76,16 +79,6 @@ class Debomatic(Parser, Process):
             exit()
         self.setlog('%(levelname)s: %(message)s',
                     dom.opts.get('debomatic', 'loglevel'))
-        gpg = GPGKeys()
-        try:
-            gpg.check_keys()
-        except DebomaticError:
-            info(_('Creating sbuild keys'))
-            try:
-                call(['sbuild-update', '--keygen'])
-            except CalledProcessError:
-                error(_('Failed to create sbuild keys'))
-                exit(1)
         self.mod_sys = Module()
         self.mod_sys.execute_hook('on_start')
         try:
@@ -95,14 +88,17 @@ class Debomatic(Parser, Process):
             exit(1)
 
     def launcher(self):
-        self.queue_files()
-        if dom.opts.getboolean('debomatic', 'inotify'):
-            try:
-                self.launcher_inotify()
-            except ImportError:
-                self.launcher_timer()
+        if self.oneshot:
+            self.queue_files([self.oneshot])
         else:
-            self.launcher_timer()
+            self.queue_files()
+            if dom.opts.getboolean('debomatic', 'inotify'):
+                try:
+                    self.launcher_inotify()
+                except ImportError:
+                    self.launcher_timer()
+            else:
+                self.launcher_timer()
 
     def launcher_inotify(self):
         import pyinotify
@@ -130,7 +126,13 @@ class Debomatic(Parser, Process):
             self.queue_files()
 
     def queue_files(self, filelist=None):
-        if not filelist:
+        if filelist:
+            filelist = [os.path.join(self.incoming, os.path.basename(f))
+                        for f in filelist]
+            for f in filelist:
+                if not os.path.isfile(f):
+                    filelist.remove(f)
+        else:
             try:
                 filelist = os.listdir(self.incoming)
             except OSError:
@@ -150,6 +152,8 @@ class Debomatic(Parser, Process):
                         debug(_('Thread for %s scheduled') % filename)
             elif filename.endswith('.commands'):
                 Command(filename)
+        if self.oneshot:
+            self.shutdown()
 
     def setlog(self, fmt, level='info'):
         loglevels = {'error': ERROR,
