@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2015 Luca Falavigna
+# Copyright (C) 2007-2016 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -19,8 +19,8 @@
 
 import os
 from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_UN
-from re import findall, match, DOTALL
-from subprocess import check_output, Popen, PIPE, CalledProcessError
+from re import findall, DOTALL
+from subprocess import Popen, PIPE
 
 from Debomatic import dom
 from .exceptions import DebomaticError
@@ -80,35 +80,3 @@ class GPG:
 
     def error(self):
         return self._error
-
-
-class GPGKeys:
-
-    def __init__(self):
-        self._private = '/var/lib/sbuild/apt-keys/sbuild-key.sec'
-        self._public = '/var/lib/sbuild/apt-keys/sbuild-key.pub'
-
-    def check_keys(self):
-        try:
-            with open(os.devnull, 'w') as fd:
-                gpgresult = check_output(['gpg', '--with-fingerprint',
-                                         self._private], stderr=fd)
-        except CalledProcessError:
-            self._error = _('%s not found') % self._private
-            raise DebomaticError
-        if not match(b'sec\s+\d+\S/\S{8}', gpgresult):
-            self._error = _('%s is not a valid GPG key') % self._private
-            raise DebomaticError
-        try:
-            with open(os.devnull, 'w') as fd:
-                gpgresult = check_output(['gpg', '--with-fingerprint',
-                                         self._public], stderr=fd)
-        except CalledProcessError:
-            self._error = _('%s not found') % self._public
-            raise DebomaticError
-        if not match(b'pub\s+\d+\S/\S{8}', gpgresult):
-            self._error = _('%s is not a valid GPG key') % self._public
-            raise DebomaticError
-
-    def error(self):
-        return self._error
